==> dynapack-0.4.2.tgz: package/test/diamond/bundles/1.js <==
(function(bundleId, bundle) {
  var loadBundles = window['dynapackLoadBundles'],
      __bundles = 'dynapackBundles',
      bundles = window[__bundles];
  if (!bundles) bundles = window[__bundles] = {};
  bundles[bundleId] = bundle;
  loadBundles && loadBundles();
})//(BUNDLE_ID, [MODULES, ROOTS]);
("1.js", [{"0":function(module, exports, require) {var ensure = require("2");
var latency = require("1");
var b = "3";
var c = "5";

var notify = document.getElementById('notify');

// Inside the dynapack test suite, a js bundle fetch is delayed by
// 200 ms. The following module c fetch should lead to 2 bundle
// downloads (b/c we have a dyn dep diamond situation); these downloads
// should happen IN PARALLEL. This means it should take roughly 200ms
// for the fetch callback to run.

//setTimeout(function() {
  notify.textContent = 'fetching module c...';
  var start = (new Date()).getTime();
  ensure([c], function(err) {
    console.log('got here???');
    var msg = (
      'Expect ' + latency.toString() + 'ms load time. ' +
      'Time taken: ' +
      ((new Date()).getTime() - start).toString() +
      'ms'
    );
    notify.textContent = msg;
    iso.ok(msg);
  });
//}, 20);
},"1":function(module, exports, require) {module.exports = 200;
},"2":function(module, exports, require) {/**
 *  Call our require.ensure under the attached context. Therefore,
 *  require.ensure must reference only global closure variables.
 */

module.exports = function() {
  require.ensure.apply(this, arguments);
};
}},{"3":["2.js","6.js"],"5":["4.js","6.js"]}]);

==> dynapack-0.4.6.tgz: package/test/diamond/bundles/1.js <==
(function(bundleId, bundle) {
  var loadBundles = window['dynapackLoadBundles'],
      __bundles = 'dynapackBundles',
      bundles = window[__bundles];
  if (!bundles) bundles = window[__bundles] = {};
  bundles[bundleId] = bundle;
  loadBundles && loadBundles();
})//(BUNDLE_ID, [MODULES, ROOTS]);
("1.js", [{"1":function(module, exports, require) {/**
 *  Call our require.ensure under the attached context. Therefore,
 *  require.ensure must reference only global closure variables.
 */

module.exports = function() {
  require.ensure.apply(this, arguments);
};
},"0":function(module, exports, require) {var ensure = require("1");
var latency = require("5");
var b = "2";
var c = "4";

var notify = document.getElementById('notify');

// Inside the dynapack test suite, a js bundle fetch is delayed by
// 200 ms. The following module c fetch should lead to 2 bundle
// downloads (b/c we have a dyn dep diamond situation); these downloads
// should happen IN PARALLEL. This means it should take roughly 200ms
// for the fetch callback to run.

//setTimeout(function() {
  notify.textContent = 'fetching module c...';
  var start = (new Date()).getTime();
  ensure([c], function(err) {
    console.log('got here???');
    var msg = (
      'Expect ' + latency.toString() + 'ms load time. ' +
      'Time taken: ' +
      ((new Date()).getTime() - start).toString() +
      'ms'
    );
    notify.textContent = msg;
    iso.ok(msg);
  });
//}, 20);
},"5":function(module, exports, require) {module.exports = 200;
}},{"2":["2.js","6.js"],"4":["4.js","6.js"]}]);
